# createfastapiapp

FastAPI app creation template

[![Linting](../../actions/workflows/lint.yml/badge.svg)](../../actions/workflows/lint.yml)

[![MacOS_Tests](../../actions/workflows/push_macos.yml/badge.svg)](../../actions/workflows/push_macos.yml)
[![Ubuntu_Tests](../../actions/workflows/push_ubuntu.yml/badge.svg)](../../actions/workflows/push_ubuntu.yml)
[![Win_Tests](../../actions/workflows/push_win.yml/badge.svg)](../../actions/workflows/push_win.yml)

To develop software, run `. ./activate.sh`

# Windows

This environment requires you to use `git-bash`.

# Linting

Run `./lint.sh` to find linting errors using `pylint`, `flake8` and `mypy`.

# Versions

  * 1.0.4: Allows empty github url
  * 1.0.3: Adds post install instructions to the command line.
  * 1.0.2: Remove trailing `.git` and `/` for githurl repo input
  * 1.0.1: Adds +x to all shell scripts
  * 1.0.0: Initial commit